# Developers

### **Prof. Jing Liu**
**Hainan University**  
**Email:** <liujing@hainanu.edu.cn>  
**Biography:** Prof. Liu is currently a full-time professor at the Center for Theoretical Physics 
and School of Physics and Optoelectronic Engineering, Hainan University. His main research interests 
focus on the topics in quantum metrology, quantum control, quantum information theory, and 
foundations of quantum mechanics, especially the design of high-precision measurement schemes 
using the features of quantum mechanics.

---

### **Prof. Rafał Demkowicz-Dobrzański**  
**University of Warsaw**  
**Email:** <Rafal.Demkowicz-Dobrzanski@fuw.edu.pl>  
**Biography:** Prof. Demkowicz-Dobrzański is a faculty at the Faculty of Physics, 
University of Warsaw. He is a theorist actively working in the field of quantum metrology, 
who developed methods to identify fundamental limits in quantum metrology in presence of 
decoherence.

---
### **Mr. Huai-Ming Yu**  
**Huazhong University of Science and Technology**  
**Email:** <HuaimingYuuu@gmail.com>  
**Biography:** Mr. Yu is a M.Sc. student at the School of Physics, Huazhong University of 
Science and Technology. His research interests lie primarily in the fields of quantum information,
quantum control, quantum foundations, as well as scientific programming and its applications in
quantum technology.

---

# Contributors

### **Mr. Zheng-Wei An**
**Huazhong University of Science and Technology**  

---

# Advisors

### **Prof. Haidong Yuan**  
**The Chinese University of Hong Kong**  
**Biography:** Prof. Yuan is an associate professor at the Department of Mechanical 
and Automation Engineering, The Chinese University of Hong Kong.

---

### **Prof. Xiaoguang Wang**  
**Zhejiang Sci-Tech University**  
**Biography:** Prof. Wang used to be a full-time professor at the Department of Physics, Zhejiang University and now is a full-time professor at the Department of Physics, Zhejiang Sci-Tech University.


---
# Former Developer

### **Dr. Mao Zhang**  
**Email:** <zhangmao2018@foxmail.com>  
**Biography:** Dr. Zhang is now working at the United Imaging Healthcare Co., Ltd.. She used to be a Ph.D. student in the National Precise Gravity Measurement Facility, School of Physics, Huazhong University of Science and Technology. 
